<?php
/**
 * Template Name: Contact Us Template                                            
 * The template for displaying about us page.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Corporate Education Pro 1.0
 */

get_header(); 
$options = corporate_education_pro_get_theme_options(); ?>

<section id="contact-form" class="page-section less-top-padding">
    <div class="white-shape top move-up left innerpage"></div>
    <div class="white-shape top full-width innerpage"></div>
    <div class="white-shape bottom move-down right"></div>
    <div class="white-shape bottom move-down full-width"></div>
    
    <div class="wrapper">
        <div class="entry-content">
            <?php  
            while ( have_posts() ) : the_post();
            	the_content();
            endwhile;
            ?>

            <div class="contact-information-wrapper col-2 clear">
                <div class="triangle top left">&#9650;</div>
                <div class="white-shape top right"></div>
                <div class="white-shape top"></div>
                <div class="blue-shape bottom move-down right"></div>

                <div class="row">
                    <div class="hentry">
                        <h2 class="form-title"><?php esc_html_e( 'Send us a Message', 'corporate-education-pro' ); ?></h2>
                        <?php if ( ! empty( $options['contact_page_form'] ) ) :
							echo do_shortcode( wp_kses_post( $options['contact_page_form'] ) );
						endif; ?>
                    </div><!-- .hentry -->

                    <div class="hentry">
                        <div class="contact-details-wrapper">
							<?php if ( is_active_sidebar( 'contact-page-widget' ) ) :
								dynamic_sidebar( 'contact-page-widget' );
							endif; ?>                            
                        </div><!-- .contact-details-wrapper -->
                    </div><!-- .hentry -->
                </div><!-- .row -->
            </div><!-- .col-2 -->
        </div><!-- .entry-content -->
    </div><!-- .wrapper -->
</section><!-- #contact-form -->

<?php 
add_action( 'corporate_education_pro_contact_map_action', 'corporate_education_pro_contact_map', 10 );
function corporate_education_pro_contact_map() {
	$options = corporate_education_pro_get_theme_options();
	if ( true === $options['contact_map_enable'] ) : 
		$map_content_type       = ! empty( $options['map_content_type'] ) ? $options['map_content_type'] : '';
		$map_content_embed      = ! empty( $options['map_content_embed'] ) ? $options['map_content_embed'] : '';
	    $map_content_shortcode  = ! empty( $options['map_content_shortcode'] ) ? $options['map_content_shortcode'] : '';

	    if ( 'shortcode' === $map_content_type ) {
	    	if ( empty( $map_content_shortcode ) )
	    		return false;
	    }
    	elseif ( 'embed' === $map_content_embed ) {
    		if ( empty( $map_content_embed ) )
    			return false;
    	}
	?>
		<section id="map-section" class="map">
	        <div class="map-overlay"></div>
	        <?php 
	        if ( $map_content_type == 'shortcode' ){
	            echo do_shortcode( wp_kses_post( $map_content_shortcode ) );
	        } elseif ( $map_content_type == 'embed'  ) {
	            echo corporate_education_pro_santize_iframe_map( $map_content_embed );
	        }
	        ?>
	    </section>

	<?php endif;
}

/**
 * corporate_education_pro_contact_map_action hook
 *
 * @hooked corporate_education_pro_contact_map -  10
 *
 */
do_action( 'corporate_education_pro_contact_map_action' );

get_footer();
