<?php
/**
 * Service Template options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

// Add panel for section options
$wp_customize->add_panel( 'corporate_education_pro_service_panel' , array(
    'title'      => esc_html__( 'Service Template','corporate-education-pro' ),
    'description'=> esc_html__( 'Service Template Options', 'corporate-education-pro' ),
    'priority'   => 150,
) );

/*
 * Goal Section
 */
$wp_customize->add_section( 'corporate_education_pro_goal_section', array(
	'title'             => esc_html__( 'Goal Section','corporate-education-pro' ),
	'description'       => esc_html__( 'Goal section options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_service_panel',
) );

// main service Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[goal_section_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['goal_section_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[goal_section_enable]', array(
	'label'            	=> esc_html__( 'Enable Goal Section ', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_goal_section',
	'type'             	=> 'checkbox',
) );

// Destination Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[goal_intro_content_type]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
	'default'			=> $options['goal_intro_content_type'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[goal_intro_content_type]', array(
	'label'            	=> esc_html__( 'Goal Intro Content Type', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Select content type to display goals.', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_goal_section',
	'active_callback'   => 'corporate_education_pro_is_goal_section_enable',
	'type'             	=> 'select',
	'choices'			=> corporate_education_pro_message(),
) );

// // team Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[goal_intro_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[goal_intro_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_service_goal_intro_content_post',
	'label'             => esc_html__( 'Input Post Id', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_goal_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[goal_intro_content_page]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_page'
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[goal_intro_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'corporate-education-pro' ),
	'section'        	=> 'corporate_education_pro_goal_section',
	'active_callback' 	=> 'corporate_education_pro_service_goal_intro_content_page',
	'type'				=> 'dropdown-pages'
) );

// Show title setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[goal_intro_content_title]', array(
	'default' 			=> $options['goal_intro_content_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[goal_intro_content_title]', array(
	'label'           	=> esc_html__( 'Title', 'corporate-education-pro' ),
	'section'        	=> 'corporate_education_pro_goal_section',
	'active_callback' 	=> 'corporate_education_pro_service_goal_intro_content_custom',
	'type'				=> 'text'
) );

// Show sub title setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[goal_intro_content_sub_title]', array(
	'default' 			=> $options['goal_intro_content_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[goal_intro_content_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'corporate-education-pro' ),
	'section'        	=> 'corporate_education_pro_goal_section',
	'active_callback'   => 'corporate_education_pro_is_goal_section_enable',
	'type'				=> 'text'
) );

// Show title setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[goal_intro_content_description]', array(
	'default' 			=> $options['goal_intro_content_description'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[goal_intro_content_description]', array(
	'label'           	=> esc_html__( 'Description', 'corporate-education-pro' ),
	'section'        	=> 'corporate_education_pro_goal_section',
	'active_callback' 	=> 'corporate_education_pro_service_goal_intro_content_custom',
	'type'				=> 'textarea'
) );

// team post hr setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[goal_intro_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Customize_Horizontal_Line( $wp_customize, 'corporate_education_pro_theme_options[goal_intro_hr]',
	array(
		'section'         => 'corporate_education_pro_goal_section',
		'active_callback'   => 'corporate_education_pro_is_goal_section_enable',
		'type'			  => 'hr'
) ) );

// Destination Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[goal_content_type]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
	'default'			=> $options['goal_content_type'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[goal_content_type]', array(
	'label'            	=> esc_html__( 'Goal Content Type', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Select content type to display goals.', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_goal_section',
	'active_callback'   => 'corporate_education_pro_is_goal_section_enable',
	'type'             	=> 'select',
	'choices'			=> corporate_education_pro_goal(),
) );

// goal Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[goal_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[goal_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_service_goal_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please input 3 post ids. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_goal_section',
	'type'				=> 'text',
) );

// goal Section page setting and control
for ( $i = 1; $i <= 3; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'corporate_education_pro_theme_options[goal_content_page_'.$i.']', array(
		'sanitize_callback' => 'corporate_education_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'corporate_education_pro_theme_options[goal_content_page_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'corporate-education-pro' ), $i ),
		'section'        	=> 'corporate_education_pro_goal_section',
		'active_callback' 	=> 'corporate_education_pro_service_goal_content_page',
		'type'				=> 'dropdown-pages'
	) );
}

/*
 * Main Service Section
 */
$wp_customize->add_section( 'corporate_education_pro_main_service_section', array(
	'title'             => esc_html__( 'Main Service Section','corporate-education-pro' ),
	'description'       => esc_html__( 'Main Service section options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_service_panel',
) );

// main service Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[main_service_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['main_service_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[main_service_enable]', array(
	'label'            	=> esc_html__( 'Enable Main Service', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_main_service_section',
	'type'             	=> 'checkbox',
) );

// main service Section background setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[main_service_image]', array(
	'default'           => $options['main_service_image'],
	'sanitize_callback' => 'corporate_education_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'corporate_education_pro_theme_options[main_service_image]',
		array(
		'label'       		=> esc_html__( 'Select Highlight Image', 'corporate-education-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'corporate-education-pro' ), 390, 460 ),
		'section'     		=> 'corporate_education_pro_main_service_section',
		'active_callback'	=> 'corporate_education_pro_is_main_service_enable',
) ) );

// main service Section title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[main_service_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['main_service_title'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[main_service_title]', array(
	'label'            	=> esc_html__( 'Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_main_service_section',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_main_service_enable',
) );

// main service Section sub title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[main_service_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['main_service_sub_title'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[main_service_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_main_service_section',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_main_service_enable',
) );

// main service Section content type setting and control.
// options are same as goal section
$wp_customize->add_setting( 'corporate_education_pro_theme_options[main_service_content_type]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
	'default'			=> $options['main_service_content_type'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[main_service_content_type]', array(
	'label'            	=> esc_html__( 'Main Services Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_main_service_section',
	'type'             	=> 'select',
	'choices'			=> corporate_education_pro_goal(),
	'active_callback'	=> 'corporate_education_pro_is_main_service_enable',
) );

// goal Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[main_service_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[main_service_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_main_service_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please input 4 post ids. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_main_service_section',
	'type'				=> 'text',
) );

// goal Section page setting and control
for ( $i = 1; $i <= 4; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'corporate_education_pro_theme_options[main_service_content_page_'.$i.']', array(
		'sanitize_callback' => 'corporate_education_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'corporate_education_pro_theme_options[main_service_content_page_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'corporate-education-pro' ), $i ),
		'section'        	=> 'corporate_education_pro_main_service_section',
		'active_callback' 	=> 'corporate_education_pro_main_service_content_page',
		'type'				=> 'dropdown-pages'
	) );
}


/*
 * Quality Service Section
 */
$wp_customize->add_section( 'corporate_education_pro_quality_service_section', array(
	'title'             => esc_html__( 'Quality Service Section','corporate-education-pro' ),
	'description'       => esc_html__( 'Quality Service section options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_service_panel',
) );

// main service Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[quality_service_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['quality_service_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[quality_service_enable]', array(
	'label'            	=> esc_html__( 'Enable Quality Service', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_quality_service_section',
	'type'             	=> 'checkbox',
) );

// quality service Section title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[quality_service_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['quality_service_title'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[quality_service_title]', array(
	'label'            	=> esc_html__( 'Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_quality_service_section',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_quality_service_enable',
) );

// quality service Section sub title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[quality_service_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['quality_service_sub_title'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[quality_service_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_quality_service_section',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_quality_service_enable',
) );

// quality service Section content type setting and control.
// options are same as study guide
$wp_customize->add_setting( 'corporate_education_pro_theme_options[quality_service_content_type]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
	'default'			=> $options['quality_service_content_type'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[quality_service_content_type]', array(
	'label'            	=> esc_html__( 'Quality Services Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_quality_service_section',
	'type'             	=> 'select',
	'choices'			=> corporate_education_pro_study_guide(),
	'active_callback'	=> 'corporate_education_pro_is_quality_service_enable',
) );

// Add destination number setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[quality_service_count]', array(
	'default'           => $options['quality_service_count'],
	'sanitize_callback' => 'corporate_education_pro_sanitize_number_range',
	'validate_callback' => 'corporate_education_pro_validate_quality_service_count',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[quality_service_count]', array(
	'label'           	=> esc_html__( 'Number of Quality Services', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 9. Please input the valid number and save.', 'corporate-education-pro' ),
	'section'         	=> 'corporate_education_pro_quality_service_section',
	'type'            	=> 'number',
	'active_callback' 	=> 'corporate_education_pro_quality_service_content_category',
	'input_attrs'     	=> array(
		'max' 	=> 9,
		'min' 	=> 3,
		'style' => 'width:100px'
	)
) );

// goal Section category setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[quality_service_content_category]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[quality_service_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_quality_service_section',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_quality_service_content_category',
) ) );

// goal Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[quality_service_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[quality_service_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_quality_service_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please input max 9 post ids. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_quality_service_section',
	'type'				=> 'text',
) );
