<?php 
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_service_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if service is enabled
        $enable_service = apply_filters( 'corporate_education_pro_section_status', true, 'service_enable' );

        if ( true !== $enable_service ) {
            return false;
        }

        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_service_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render service section now.
        corporate_education_pro_render_service_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_primary_content_action', 'corporate_education_pro_add_service_section', 30 );


if ( ! function_exists( 'corporate_education_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input service section details.
    */
    function corporate_education_pro_get_service_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // service intro type
        $service_intro_content_type  = $options['service_intro_content_type'];

        $content = array();
        switch ( $service_intro_content_type ) {
          	case 'demo':
                $content['intro'][0]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/featured-service.jpg';
                $content['intro'][0]['img_array'][1] = 400;
                $content['intro'][0]['img_array'][2] = 270;
                $content['intro'][0]['title']    = esc_html__( 'Best For You', 'corporate-education-pro' );
                $content['intro'][0]['url']      = '#';
                $content['intro'][0]['excerpt']  = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam eget augue quis elit tempor laoreet. Vestibulum purus quam, vestibulum sed malesuada id, hendrerit nec dolor nulla risus erat.', 'corporate-education-pro' );
            break;        

            case 'custom':
                $content['intro'][0]['img_array'][0] = ! empty( $options['service_intro_image'] ) ? $options['service_intro_image'] : '';
                if ( ! empty( $options['service_intro_image'] ) ) {
                    $content['intro'][0]['img_array'][1] = 400;
                    $content['intro'][0]['img_array'][2] = 270;
                }
                $content['intro'][0]['url']      = ! empty( $options['service_intro_btn_url'] ) ? $options['service_intro_btn_url'] : '';
                $content['intro'][0]['title']    = ! empty( $options['service_intro_title'] ) ? $options['service_intro_title'] : '';
                $content['intro'][0]['excerpt']  = ! empty( $options['service_intro_description'] ) ? $options['service_intro_description'] : '';
            break;   

            case 'post':
                $post_id = '';
                
                if ( ! empty( $options['service_intro_content_post'] ) )
                    $post_id = absint( $options['service_intro_content_post'] );

                // Bail if no valid pages are selected.
                if ( empty( $post_id ) ) {
                    return $input;
                }

                $img_array = null;
                if ( has_post_thumbnail( $post_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'post-thumbnail' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-400x270.jpg';
                    $img_array[1] =  400;
                    $img_array[2] =  270;
                }
                if ( isset( $img_array ) ) {
                    $content['intro'][0]['img_array'] = $img_array;
                }

                $content['intro'][0]['title']    = get_the_title( $post_id );
                $content['intro'][0]['url']      = get_the_permalink( $post_id );
                $content['intro'][0]['excerpt']  = corporate_education_pro_trim_content( 28, get_post( $post_id ) );
                                            
          	break;

            case 'page':
                $page_id = '';
                
                if ( ! empty( $options['service_intro_content_page'] ) )
                    $page_id = absint( $options['service_intro_content_page'] );

                // Bail if no valid pages are selected.
                if ( empty( $page_id ) ) {
                    return $input;
                }

                $img_array = null;
                if ( has_post_thumbnail( $page_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'post-thumbnail' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-400x270.jpg';
                    $img_array[1] =  400;
                    $img_array[2] =  270;
                }
                if ( isset( $img_array ) ) {
                    $content['intro'][0]['img_array'] = $img_array;
                }
                $content['intro'][0]['title']    = get_the_title( $page_id );
                $content['intro'][0]['url']      = get_the_permalink( $page_id );
                $content['intro'][0]['excerpt']  = corporate_education_pro_trim_content( 28, get_post( $page_id ) );
                                            
            break;
        }

        // service type
        $service_content_type  = $options['service_content_type'];

        switch ( $service_content_type ) {
            case 'demo':
                $service_title = array(
                    esc_html__( 'Best Place', 'corporate-education-pro' ),
                    esc_html__( 'Quality Education', 'corporate-education-pro' ),
                    esc_html__( 'Easy Learning', 'corporate-education-pro' ),
                    esc_html__( 'Qualified Teacher', 'corporate-education-pro' ),
                    );
                $service_icon = array(
                    esc_attr__( 'fa-map-marker', 'corporate-education-pro' ),
                    esc_attr__( 'fa-book', 'corporate-education-pro' ),
                    esc_attr__( 'fa-desktop', 'corporate-education-pro' ),
                    esc_attr__( 'fa-user', 'corporate-education-pro' ),
                    );
                for ( $i = 0; $i <= 3; $i++ ) {
                    $content['services'][$i]['title']   = $service_title[$i];
                    $content['services'][$i]['icon']    = $service_icon[$i];
                    $content['services'][$i]['url']     = '#';
                    $content['services'][$i]['excerpt'] = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam eget augue quis elit tempor laoreet hendrerit nec dolor risus. ', 'corporate-education-pro' );
                }
            break; 

            case 'page':
                $ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    $id = null;
                    if ( isset( $options[ 'service_content_page_'.$i ] ) ) {
                        $id = $options[ 'service_content_page_'.$i ];
                    }
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $ids,
                );
            break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['service_content_category'] ) ) {
                    $cat_id = $options['service_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => 4,
                );
            break;

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['service_content_post'] ) )
                    $ids = ( array ) $options['service_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 4,
                );                             
            break;

        } 

        if ( 'demo' != $service_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 0;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $icon = get_post_meta( $post_id, 'corporate-education-pro-post-icon', true );
                    $content['services'][$i]['title']   = get_the_title( $post_id );
                    $content['services'][$i]['url']     = get_the_permalink( $post_id );
                    $content['services'][$i]['excerpt'] = corporate_education_pro_trim_content( 20, $post  );
                    $content['services'][$i]['icon']    = ! empty( $icon ) ? $icon : 'fa-tint' ;
                    $i++;
                endforeach;
            endif;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'corporate_education_pro_filter_service_section_details', 'corporate_education_pro_get_service_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_service_section' ) ) :
    /**
    * Start service section
    *
    * @return string service content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_service_section( $content_details ) {
        $options    = corporate_education_pro_get_theme_options();
        $service_sub_title  = ! empty( $options['service_intro_sub_title'] ) ? $options['service_intro_sub_title'] : '';
        $readmore   = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Read More', 'corporate-education-pro' );
        $readmore   = ( 'custom' == $options['service_intro_content_type'] ) ? $options['service_intro_btn_label'] : $readmore; 

        if ( empty( $content_details ) ) {
            return;
        }
        ?>
        <section id="featured-services">
            <div class="gray-shape leftalign"></div>
            <div class="gray-shape top move-up left"></div>

            <div class="blue-shape bottom move-down right"></div>
            
            <div class="featured-services-wrapper col-2">
                <?php foreach ( $content_details['intro'] as $content_detail ) : ?>
                    <div class="hentry">
                        <div class="left-half page-section">
                            <?php if ( ! empty( $content_detail['img_array'] ) ) : ?>
                                <figure class="featured-image">
                                    <img src="<?php echo esc_url( $content_detail['img_array'][0] ) ?>" width="<?php echo esc_attr( $content_detail['img_array'][1] ); ?>" height="<?php echo esc_attr( $content_detail['img_array'][2] ); ?>" alt="<?php echo esc_attr( $content_detail['title'] ); ?>">
                                </figure>
                            <?php endif; ?>

                            <header class="entry-header">
                                <h2 class="entry-title"><?php echo esc_html( $content_detail['title'] ); ?></h2>
                                <?php if ( ! empty( $service_sub_title ) ) : ?>
                                    <p class="entry-title-desc"><?php echo esc_html( $service_sub_title ); ?></p>
                                <?php endif; ?>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content_detail['excerpt'] ); ?></p>
                                <?php if ( ! empty( $content_detail['url'] ) ) : ?>
                                    <div class="view-more">
                                        <a href="<?php echo esc_url( $content_detail['url'] ) ?>" class="btn btn-blue-transparent"><?php echo esc_html( $readmore ); ?></a>
                                    </div>
                                <?php endif; ?>
                            </div><!-- .entry-content -->
                        </div><!-- .lefthalf -->
                    </div><!-- .hentry -->
                <?php endforeach; ?>
            
                <div class="hentry">
                    <div class="right-half page-section">
                        <div class="services-wrapper">
                            <?php if ( ! empty( $content_details['services'] ) ) :
                                foreach ( $content_details['services'] as $content_detail ) : ?>
                                    <div class="service">
                                        <div class="icon-container alignleft">
                                            <i class="fa <?php echo esc_attr( $content_detail['icon'] ); ?>"></i>
                                        </div><!-- .icon-container -->
                                        <h5 class="featured-title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                        <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                    </div><!-- .service -->
                                <?php endforeach; 
                            endif; ?>    
                        </div><!-- .services-wrapper -->
                    </div><!-- .righthalf -->
                </div><!-- .hentry -->
            </div><!-- .featured-servies-wrapper -->
        </section><!-- #featured-services -->
    <?php }
endif;
