<?php
/**
 * Template part for displaying team post.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

$options = corporate_education_pro_get_theme_options();
?>

<div id="primary" class="content-area">
	<main id="main" class="site-main" role="main">
		<div class="counselor-profile clear">
            <aside id="left-sidebar" class="widget-area">
                <section id="profile-1" class="widget widget_profile">
                    <div class="image-wrapper"> 
                        <?php if ( has_post_thumbnail() ) :  
                        	the_post_thumbnail( 'corporate-education-pro-medium', array( 'alt' => the_title_attribute( 'echo=0' ) ) );                      
                        endif; 

                        $tp_team_email = get_post_meta( get_the_ID(), 'tp_team_email_value', true ); 
                        if ( ! empty( $tp_team_email ) ) : ?>
	                        <div class="follow-buttons">
	                            <a href="mailto:<?php echo esc_attr( $tp_team_email ); ?>" class="btn-red-transparent"><?php esc_html_e( 'message me', 'corporate-education-pro' ); ?></a>
	                        </div><!-- .follow-buttons -->
	                    <?php endif; ?>

                        <h2 class="widget-title"><?php the_title(); ?></h2>

                        <?php if ( has_action( 'tp_team_designation_action' ) ) : ?>
                        	<span><?php do_action( 'tp_team_designation_action' ); ?></span>
                    	<?php endif; ?>
                    </div><!--.image-wrapper-->  

                    <?php if ( has_action( 'tp_team_social_action' ) ) : 
                    	do_action( 'tp_team_social_action' );
                    endif; ?>

                    <div class="ratings clear">
                    	<?php 
                    	$tp_team_courses = get_post_meta( get_the_ID(), 'tp_team_courses_value', true ); 
                    	if ( ! empty( $tp_team_courses ) ) :
							$team_course_count = count( $tp_team_courses );
                    	?>
	                        <div class="pull-left">
	                            <span class="numbers"><?php echo absint( $team_course_count ); ?></span>
	                            <span><?php esc_html_e( 'courses', 'corporate-education-pro' ); ?></span>
	                        </div><!-- .pull-left -->
	                    <?php endif; ?>
                        <div class="pull-left">
                            <span class="numbers">
                                <?php if ( function_exists( 'tp_education_like_button' ) ) :
									echo tp_education_like_button(); 
								endif; ?>                       
                            </span>
                            <span><?php esc_html_e( 'likes', 'corporate-education-pro' ); ?></span>
                        </div><!-- .pull-left -->
                    </div><!--.ratings-->

                    <ul class="contact-address">
                    	<?php if ( ! empty( $tp_team_email ) ) : ?>
	                        <li><a href="mailto:<?php echo esc_attr( $tp_team_email ); ?>"><i class="fa fa-envelope-o"></i><?php echo esc_html( $tp_team_email ); ?></a></li>
	                    <?php endif; 

	                    $tp_team_phone = get_post_meta( get_the_ID(), 'tp_team_phone_value', true ); 
	                    if ( ! empty( $tp_team_phone ) ) : ?>
	                        <li><a href="tel:<?php echo absint( preg_replace( '/\D+/', '', $tp_team_phone ) ); ?>"><i class="fa fa-phone"></i><?php echo esc_html( $tp_team_phone ); ?></a></li>
	                    <?php endif; 

	                    $tp_team_skype = get_post_meta( get_the_ID(), 'tp_team_skype_value', true );
						if ( ! empty( $tp_team_skype ) ) :
						?>
							<li><a href="callto:<?php echo esc_attr( $tp_team_skype ); ?>"><i class="fa fa-skype"></i><?php echo esc_html( $tp_team_skype ); ?></a></li>
						<?php
						endif;
						
						$tp_team_website = get_post_meta( get_the_ID(), 'tp_team_website_value', true );
						if ( ! empty( $tp_team_website ) ) :
						?>
							<li><a href="<?php echo esc_url( $tp_team_website ); ?>"><i class="fa fa-link"></i><?php echo esc_html( $tp_team_website ); ?></a></li> 
						<?php endif; ?>
                    </ul><!--contact-address-->
                </section><!-- .widget_profile -->
            </aside><!--#left-sidebar-->

            <div id="about-counselor">
                <header class="entry-header">
                    <h2 class="entry-title"><?php esc_html_e( 'About Me', 'corporate-education-pro' ); ?></h2>
                </header><!--.entry-header-->

                <div class="entry-content">
                    <?php the_content(); ?>
                </div><!--.entry-content-->

                <div class="tab-courses">
                    <ul class="nav-tabs tp-tabs">
                    	<?php if ( ! empty( $tp_team_courses ) ) : ?>
	                        <li class="tab-link active" data-tab="tab_courses"><a href="#."><?php esc_html_e( 'Courses', 'corporate-education-pro' ); ?></a><span><?php echo absint( $team_course_count ); ?></span></li>
	                    <?php endif; ?>
                        <li class="tab-link <?php echo empty( $tp_team_courses ) ? 'active' : ''; ?>" data-tab="tab_reviews"><a href="#."><?php esc_html_e( 'Reviews', 'corporate-education-pro' ); ?></a><span><?php echo absint( get_comments_number() ); ?></span></li>
                    </ul><!--.tabs-->

                    <?php if ( ! empty( $tp_team_courses ) ) : 
						$args = array(
							'post_type'	=> 'tp-course',
							'post__in'	=> $tp_team_courses ? (array) $tp_team_courses : ''
						);
						$posts = get_posts( $args );
					?>

	                    <div id="tab_courses" class="tab-content <?php echo ! empty( $tp_team_courses ) ? 'active' : ''; ?>">
	                        <ul>
	                            <?php foreach ( $posts as $post ) : ?>
									<li class="has-post-thumbnail clear">
										<div class="post-image">
											<a href="<?php the_permalink( $post->ID ); ?>">
												<?php 
												if ( has_post_thumbnail( $post->ID ) )
													the_post_thumbnail( 'thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) );
												else 
				                                	echo '<img src="' . get_template_directory_uri() .'/assets/uploads/no-featured-image-300x300.jpg" alt="'. esc_attr( get_the_title( $post->ID ) ) .'">';
												?>
											</a>
										</div><!-- .post-image-->
										<div class="post-wrapper">
											<div class="post-title pull-left">
												<h5><a href="<?php the_permalink( $post->ID ); ?>"><?php echo esc_html( get_the_title( $post->ID ) ); ?></a></h5>
												<?php 
												if ( function_exists( 'tp_course_price' ) ) :
													tp_course_price(); 
												endif;
												?>
											</div><!-- .post-title -->
											<a href="<?php the_permalink( $post->ID ); ?>" class="btn-black"><?php esc_html_e( 'view', 'corporate-education-pro' ); ?></a>
										</div><!-- .post-wrapper -->
									</li>
								<?php endforeach; 
								wp_reset_postdata(); ?>
	                        </ul>
	                    </div><!-- #tab_courses -->
	                <?php endif; ?>

                    <div id="tab_reviews" class="team-comment-tab tab-content <?php echo empty( $tp_team_courses ) ? 'active' : ''; ?>">
                        <?php  
						// If comments are open or we have at least one comment, load up the comment template.
						if ( comments_open() || get_comments_number() ) :
							comments_template();
						endif; ?>
                    </div><!-- #tab_reviews -->
                </div><!-- .tab-courses -->
            </div><!--#about-counselor-->
        </div><!-- .counselor-profile -->
        <?php  
    	/**
		* Hook corporate_education_pro_action_post_pagination
		*  
		* @hooked corporate_education_pro_post_pagination 
		*/
		do_action( 'corporate_education_pro_action_post_pagination' );
    	?>
	</main><!-- #main -->
</div><!-- #primary -->
